pub struct FleetArtifactRef {
pub kind: FleetArtifactKind,
pub path: PathBuf,
pub checksum: Option<String>,
pub mime_type: Option<String>,
pub size_bytes: Option<u64>,
}Expand description
Reference to an artifact produced or consumed by a task.
Fields
kind: FleetArtifactKindpath: PathBufchecksum: Option<String>mime_type: Option<String>size_bytes: Option<u64>Trait Implementations
Sourceimpl Clone for FleetArtifactRef
impl Clone for FleetArtifactRef
Sourcefn clone(&self) -> FleetArtifactRef
fn clone(&self) -> FleetArtifactRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FleetArtifactRef
impl Debug for FleetArtifactRef
Sourceimpl<'de> Deserialize<'de> for FleetArtifactRef
impl<'de> Deserialize<'de> for FleetArtifactRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FleetArtifactRef
Sourceimpl PartialEq for FleetArtifactRef
impl PartialEq for FleetArtifactRef
Sourcefn eq(&self, other: &FleetArtifactRef) -> bool
fn eq(&self, other: &FleetArtifactRef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FleetArtifactRef
impl Serialize for FleetArtifactRef
impl StructuralPartialEq for FleetArtifactRef