Crate codewhale_protocol

Crate codewhale_protocol 

Modules

fleet
Agent Fleet control-plane protocol types.
runtime
workroom
Workroom types — durable chat-native containers for threaded agent work.

Structs

AppResponse
Response to an AppRequest.
ApprovalDecisionRequest
A user’s approval decision sent in response to an approval request.
Envelope
ExecApprovalRequestEvent
An event requesting user approval for a command execution or patch application.
LocalShellParams
Parameters for executing a local shell command.
McpStartupCompleteEvent
Summary event emitted once all MCP servers have finished starting.
McpStartupFailure
Details of an MCP server that failed to start.
McpStartupUpdateEvent
A progress update for a single MCP server’s startup.
NetworkApprovalContext
Context about a network access request that requires approval.
NetworkPolicyAmendment
A proposed amendment to the network access policy for a specific host.
PromptRequest
A simple prompt request that sends text to the model and returns output.
PromptResponse
Response to a PromptRequest.
Thread
ThreadForkParams
ThreadGoal
ThreadGoalClearParams
ThreadGoalGetParams
ThreadGoalProgressParams
ThreadGoalSetParams
ThreadListParams
ThreadReadParams
ThreadResponse
Response to a ThreadRequest.
ThreadResumeParams
ThreadSetNameParams
ThreadStartParams
UserInputAnswerEvent
One answer to a clarification question.
UserInputOptionEvent
A selectable option presented to the user in a clarification question.
UserInputQuestionEvent
A single clarification question posed to the user.
UserInputRequestEvent
An event requesting structured user input via a model-tool call.

Enums

AppRequest
Application-level requests that are not tied to a specific thread.
AskForApproval
Policy controlling when the agent must ask the user for approval before acting.
EventFrame
A single streaming event frame emitted during agent execution.
McpStartupStatus
Status of an MCP server during startup.
NetworkPolicyRuleAction
Action to take for a network policy rule.
ResponseChannel
The channel a response delta is being written to.
ReviewDecision
A user’s decision on an approval request.
SessionSource
ThreadGoalStatus
ThreadRequest
ThreadStatus
ToolKind
Classification of tool invocation origin.
ToolOutput
The result of a tool call, discriminated by tool type.
ToolPayload
The payload of a tool call, discriminated by tool type.