Modules
Structs
- AppResponse
- Response to an
AppRequest. - Approval
Decision Request - A user’s approval decision sent in response to an approval request.
- Envelope
- Exec
Approval Request Event - An event requesting user approval for a command execution or patch application.
- Local
Shell Params - Parameters for executing a local shell command.
- McpStartup
Complete Event - Summary event emitted once all MCP servers have finished starting.
- McpStartup
Failure - Details of an MCP server that failed to start.
- McpStartup
Update Event - A progress update for a single MCP server’s startup.
- Network
Approval Context - Context about a network access request that requires approval.
- Network
Policy Amendment - A proposed amendment to the network access policy for a specific host.
- Prompt
Request - A simple prompt request that sends text to the model and returns output.
- Prompt
Response - Response to a
PromptRequest. - Thread
- Thread
Fork Params - Thread
Goal - Thread
Goal Clear Params - Thread
Goal GetParams - Thread
Goal Progress Params - Thread
Goal SetParams - Thread
List Params - Thread
Read Params - Thread
Response - Response to a
ThreadRequest. - Thread
Resume Params - Thread
SetName Params - Thread
Start Params
Enums
- AppRequest
- Application-level requests that are not tied to a specific thread.
- AskFor
Approval - Policy controlling when the agent must ask the user for approval before acting.
- Event
Frame - A single streaming event frame emitted during agent execution.
- McpStartup
Status - Status of an MCP server during startup.
- Network
Policy Rule Action - Action to take for a network policy rule.
- Response
Channel - The channel a response delta is being written to.
- Review
Decision - A user’s decision on an approval request.
- Session
Source - Thread
Goal Status - Thread
Request - Thread
Status - Tool
Kind - Classification of tool invocation origin.
- Tool
Output - The result of a tool call, discriminated by tool type.
- Tool
Payload - The payload of a tool call, discriminated by tool type.